package Bundle::Locale::CLDR::Europe;

use version;

our $VERSION = version->declare('v0.44.1');

=head1 NAME

Bundle::Locale::CLDR::Europe

=head1 CONTENTS

Bundle::Locale::CLDR::Easterneurope 0.44.1

Bundle::Locale::CLDR::Westerneurope 0.44.1

Bundle::Locale::CLDR::Northerneurope 0.44.1

Bundle::Locale::CLDR::Southerneurope 0.44.1

Locale::CLDR::Locales::En::Latn::001 0.44.1

Locale::CLDR::Locales::En::Latn::150 0.44.1


=cut

1;

